.. Django IPRestrict documentation master file, created by
   sphinx-quickstart on Wed Aug 15 11:50:03 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Django IP Restrict
==================

Django IPRestrict is an app that can be used to restrict access to your Django project by IP addresses.

The restriction can be for the whole site or sections of it.

IP addresses can be specific IP addresses, ranges of IP addresses or IP addresses from given countries.

The code is released under BSD license and it is hosted on github at https://github.com/muccg/django-iprestrict/.


Table of Contents
=================

.. toctree::
    :maxdepth: 2

    installation
    configuration
    changing_and_reloading_rules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

